@@ -27,19 +27,29 @@ package com.sun.jndi.dns;
 
 import java.io.IOException;
 import java.io.UncheckedIOException;
-import java.net.DatagramSocket;
-import java.net.DatagramPacket;
 import java.net.InetAddress;
 import java.net.InetSocketAddress;
 import java.net.PortUnreachableException;
 import java.net.Socket;
 import java.net.SocketTimeoutException;
+import java.nio.ByteBuffer;
+import java.nio.channels.ClosedSelectorException;
+import java.nio.channels.DatagramChannel;
+import java.nio.channels.SelectionKey;
+import java.nio.channels.Selector;
 import java.security.SecureRandom;
-import javax.naming.*;
+import javax.naming.CommunicationException;
+import javax.naming.ConfigurationException;
+import javax.naming.NameNotFoundException;
+import javax.naming.NamingException;
+import javax.naming.OperationNotSupportedException;
+import javax.naming.ServiceUnavailableException;
 
+import java.util.Arrays;
 import java.util.Collections;
 import java.util.Map;
 import java.util.HashMap;
+import java.util.concurrent.locks.ReentrantLock;
 
 import sun.security.jca.JCAUtil;
 
@@ -83,15 +93,19 @@ public class DnsClient {
 
     private static final int DEFAULT_PORT = 53;
     private static final int TRANSACTION_ID_BOUND = 0x10000;
+    private static final int MIN_TIMEOUT = 50; // msec after which there are no retries.
     private static final SecureRandom random = JCAUtil.getSecureRandom();
     private InetAddress[] servers;
     private int[] serverPorts;
     private int timeout;                // initial timeout on UDP and TCP queries in ms
     private int retries;                // number of UDP retries
 
-    private final Object udpSocketLock = new Object();
-    private static final DNSDatagramSocketFactory factory =
-            new DNSDatagramSocketFactory(random);
+    private final ReentrantLock udpChannelLock = new ReentrantLock();
+
+    private final Selector udpChannelSelector;
+
+    private static final DNSDatagramChannelFactory factory =
+            new DNSDatagramChannelFactory(random);
 
     // Requests sent
     private Map<Integer, ResourceRecord> reqs;
@@ -135,15 +149,24 @@ public class DnsClient {
                 throw ne;
             }
         }
+
+        try {
+            udpChannelSelector = Selector.open();
+        } catch (IOException e) {
+            NamingException ne = new ConfigurationException(
+                    "Channel selector configuration error");
+            ne.setRootCause(e);
+            throw ne;
+        }
         reqs = Collections.synchronizedMap(
             new HashMap<Integer, ResourceRecord>());
         resps = Collections.synchronizedMap(new HashMap<Integer, byte[]>());
     }
 
-    DatagramSocket getDatagramSocket() throws NamingException {
+    DatagramChannel getDatagramChannel() throws NamingException {
         try {
             return factory.open();
-        } catch (java.net.SocketException e) {
+        } catch (IOException e) {
             NamingException ne = new ConfigurationException();
             ne.setRootCause(e);
             throw ne;
@@ -159,6 +182,10 @@ public class DnsClient {
     private Object queuesLock = new Object();
 
     public void close() {
+        try {
+            udpChannelSelector.close();
+        } catch (IOException ioException) {
+        }
         synchronized (queuesLock) {
             reqs.clear();
             resps.clear();
@@ -212,23 +239,9 @@ public class DnsClient {
                             dprint("SEND ID (" + (retry + 1) + "): " + xid);
                         }
 
-                        byte[] msg = null;
-                        msg = doUdpQuery(pkt, servers[i], serverPorts[i],
-                                            retry, xid);
-                        //
-                        // If the matching response is not got within the
-                        // given timeout, check if the response was enqueued
-                        // by some other thread, if not proceed with the next
-                        // server or retry.
-                        //
-                        if (msg == null) {
-                            if (resps.size() > 0) {
-                                msg = lookupResponse(xid);
-                            }
-                            if (msg == null) { // try next server or retry
-                                continue;
-                            }
-                        }
+                        byte[] msg = doUdpQuery(pkt, servers[i], serverPorts[i],
+                                                retry, xid);
+                        assert msg != null;
                         Header hdr = new Header(msg, msg.length);
 
                         if (auth && !hdr.authoritative) {
@@ -294,6 +307,13 @@ public class DnsClient {
                         if (caughtException == null) {
                             caughtException = e;
                         }
+                    } catch (ClosedSelectorException e) {
+                        // ClosedSelectorException is thrown by blockingReceive if
+                        // the datagram channel selector associated with DNS client
+                        // is unexpectedly closed
+                        var ce = new CommunicationException("DNS client closed");
+                        ce.setRootCause(e);
+                        throw ce;
                     } catch (NameNotFoundException e) {
                         // This is authoritative, so return immediately
                         throw e;
@@ -402,22 +422,28 @@ public class DnsClient {
                                      int port, int retry, int xid)
             throws IOException, NamingException {
 
-        int minTimeout = 50; // msec after which there are no retries.
-
-        synchronized (udpSocketLock) {
-            try (DatagramSocket udpSocket = getDatagramSocket()) {
-                DatagramPacket opkt = new DatagramPacket(
-                        pkt.getData(), pkt.length(), server, port);
-                DatagramPacket ipkt = new DatagramPacket(new byte[8000], 8000);
+        udpChannelLock.lock();
+        try {
+            try (DatagramChannel udpChannel = getDatagramChannel()) {
+                ByteBuffer opkt = ByteBuffer.wrap(pkt.getData(), 0, pkt.length());
+                byte[] data = new byte[8000];
+                ByteBuffer ipkt = ByteBuffer.wrap(data);
                 // Packets may only be sent to or received from this server address
-                udpSocket.connect(server, port);
+                InetSocketAddress target = new InetSocketAddress(server, port);
+                udpChannel.connect(target);
                 int pktTimeout = (timeout * (1 << retry));
-                udpSocket.send(opkt);
+                udpChannel.write(opkt);
 
-                // timeout remaining after successive 'receive()'
+                // timeout remaining after successive 'blockingReceive()'
                 int timeoutLeft = pktTimeout;
                 int cnt = 0;
+                boolean gotData = false;
                 do {
+                    // prepare for retry
+                    if (gotData) {
+                        Arrays.fill(data, 0, ipkt.position(), (byte) 0);
+                        ipkt.clear();
+                    }
                     if (debug) {
                         cnt++;
                         dprint("Trying RECEIVE(" +
@@ -425,22 +451,53 @@ public class DnsClient {
                                 ") for:" + xid + "    sock-timeout:" +
                                 timeoutLeft + " ms.");
                     }
-                    udpSocket.setSoTimeout(timeoutLeft);
                     long start = System.currentTimeMillis();
-                    udpSocket.receive(ipkt);
+                    gotData = blockingReceive(udpChannel, ipkt, timeoutLeft);
                     long end = System.currentTimeMillis();
-
-                    byte[] data = ipkt.getData();
-                    if (isMatchResponse(data, xid)) {
+                    assert gotData || ipkt.position() == 0;
+                    if (gotData && isMatchResponse(data, xid)) {
                         return data;
+                    } else if (resps.size() > 0) {
+                        // If the matching response is not found, check if
+                        // the response was enqueued by some other thread,
+                        // if not continue
+                        byte[] cachedMsg = lookupResponse(xid);
+                        if (cachedMsg != null) { // found in cache
+                            return cachedMsg;
+                        }
                     }
                     timeoutLeft = pktTimeout - ((int) (end - start));
-                } while (timeoutLeft > minTimeout);
-                return null; // no matching packet received within the timeout
+                } while (timeoutLeft > MIN_TIMEOUT);
+                // no matching packets received within the timeout
+                throw new SocketTimeoutException();
             }
+        } finally {
+            udpChannelLock.unlock();
         }
     }
 
+    boolean blockingReceive(DatagramChannel dc, ByteBuffer buffer, long timeout) throws IOException {
+        boolean dataReceived = false;
+        // The provided datagram channel will be used by the caller only to receive data after
+        // it is put to non-blocking mode
+        dc.configureBlocking(false);
+        var selectionKey = dc.register(udpChannelSelector, SelectionKey.OP_READ);
+        try {
+            udpChannelSelector.select(timeout);
+            var keys = udpChannelSelector.selectedKeys();
+            if (keys.contains(selectionKey) && selectionKey.isReadable()) {
+                dc.receive(buffer);
+                dataReceived = true;
+            }
+            keys.clear();
+        } finally {
+            selectionKey.cancel();
+            // Flush the canceled key out of the selected key set
+            udpChannelSelector.selectNow();
+        }
+        return dataReceived;
+    }
+
     /*
      * Sends a TCP query, and returns the first DNS message in the response.
      */
@@ -623,13 +680,13 @@ public class DnsClient {
         }
 
         //
-        // xid mis-match: enqueue the response, it may belong to some other
+        // xid mismatch: enqueue the response, it may belong to some other
         // thread that has not yet had a chance to read its response.
         // enqueue only the first response, responses for retries are ignored.
         //
         synchronized (queuesLock) {
             if (reqs.containsKey(hdr.xid)) { // enqueue only the first response
-                resps.put(hdr.xid, pkt);
+                resps.put(hdr.xid, pkt.clone());
             }
         }
 
@@ -730,7 +787,7 @@ class Tcp {
             return reader.read();
         }
         finally {
-            timeoutLeft -= System.currentTimeMillis() - start;
+            timeoutLeft -= (int) (System.currentTimeMillis() - start);
         }
     }
 
