@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -34,25 +34,25 @@ import java.util.Hashtable;
 import java.util.concurrent.ConcurrentHashMap;
 
 /**
- * The BasicPermission class extends the Permission class, and
+ * The {@code BasicPermission} class extends the {@code Permission} class, and
  * can be used as the base class for permissions that want to
- * follow the same naming convention as BasicPermission.
+ * follow the same naming convention as {@code BasicPermission}.
  * <P>
- * The name for a BasicPermission is the name of the given permission
+ * The name for a {@code BasicPermission} is the name of the given permission
  * (for example, "exit",
- * "setFactory", "print.queueJob", etc). The naming
+ * "setFactory", "print.queueJob", etc.). The naming
  * convention follows the  hierarchical property naming convention.
  * An asterisk may appear by itself, or if immediately preceded by a "."
  * may appear at the end of the name, to signify a wildcard match.
  * For example, "*" and "java.*" signify a wildcard match, while "*java", "a*b",
  * and "java*" do not.
  * <P>
- * The action string (inherited from Permission) is unused.
- * Thus, BasicPermission is commonly used as the base class for
+ * The action string (inherited from {@code Permission}) is unused.
+ * Thus, {@code BasicPermission} is commonly used as the base class for
  * "named" permissions
  * (ones that contain a name but no actions list; you either have the
  * named permission or you don't.)
- * Subclasses may implement actions on top of BasicPermission,
+ * Subclasses may implement actions on top of {@code BasicPermission},
  * if desired.
  *
  * @see java.security.Permission
@@ -82,7 +82,7 @@ public abstract class BasicPermission extends Permission
     private transient boolean exitVM;
 
     /**
-     * initialize a BasicPermission object. Common to all constructors.
+     * initialize a {@code BasicPermission} object. Common to all constructors.
      */
     private void init(String name) {
         if (name == null)
@@ -116,12 +116,12 @@ public abstract class BasicPermission extends Permission
     }
 
     /**
-     * Creates a new BasicPermission with the specified name.
+     * Creates a new {@code BasicPermission} with the specified name.
      * Name is the symbolic name of the permission, such as
      * "setFactory",
      * "print.queueJob", or "topLevelWindow", etc.
      *
-     * @param name the name of the BasicPermission.
+     * @param name the name of the {@code BasicPermission}.
      *
      * @throws NullPointerException if {@code name} is {@code null}.
      * @throws IllegalArgumentException if {@code name} is empty.
@@ -133,11 +133,11 @@ public abstract class BasicPermission extends Permission
 
 
     /**
-     * Creates a new BasicPermission object with the specified name.
-     * The name is the symbolic name of the BasicPermission, and the
-     * actions String is currently unused.
+     * Creates a new {@code BasicPermission} object with the specified name.
+     * The name is the symbolic name of the {@code BasicPermission}, and the
+     * actions {@code String} is currently unused.
      *
-     * @param name the name of the BasicPermission.
+     * @param name the name of the {@code BasicPermission}.
      * @param actions ignored.
      *
      * @throws NullPointerException if {@code name} is {@code null}.
@@ -152,7 +152,7 @@ public abstract class BasicPermission extends Permission
      * Checks if the specified permission is "implied" by
      * this object.
      * <P>
-     * More specifically, this method returns true if:
+     * More specifically, this method returns {@code true} if:
      * <ul>
      * <li> {@code p}'s class is the same as this object's class, and
      * <li> {@code p}'s name equals or (in the case of wildcards)
@@ -162,8 +162,8 @@ public abstract class BasicPermission extends Permission
      *
      * @param p the permission to check against.
      *
-     * @return true if the passed permission is equal to or
-     * implied by this permission, false otherwise.
+     * @return {@code true} if the passed permission is equal to or
+     * implied by this permission, {@code false} otherwise.
      */
     @Override
     public boolean implies(Permission p) {
@@ -193,13 +193,14 @@ public abstract class BasicPermission extends Permission
     }
 
     /**
-     * Checks two BasicPermission objects for equality.
+     * Checks two {@code BasicPermission} objects for equality.
      * Checks that {@code obj}'s class is the same as this object's class
      * and has the same name as this object.
      *
      * @param obj the object we are testing for equality with this object.
-     * @return true if {@code obj}'s class is the same as this object's class
-     *  and has the same name as this BasicPermission object, false otherwise.
+     * @return {@code true} if {@code obj}'s class is the same as this
+     * object's class and has the same name as this {@code BasicPermission}
+     * object, {@code false} otherwise.
      */
     @Override
     public boolean equals(Object obj) {
@@ -219,7 +220,7 @@ public abstract class BasicPermission extends Permission
      * Returns the hash code value for this object.
      * The hash code used is the hash code of the name, that is,
      * {@code getName().hashCode()}, where {@code getName} is
-     * from the Permission superclass.
+     * from the {@code Permission} superclass.
      *
      * @return a hash code value for this object.
      */
@@ -231,7 +232,7 @@ public abstract class BasicPermission extends Permission
     /**
      * Returns the canonical string representation of the actions,
      * which currently is the empty string "", since there are no actions for
-     * a BasicPermission.
+     * a {@code BasicPermission}.
      *
      * @return the empty string "".
      */
@@ -241,16 +242,16 @@ public abstract class BasicPermission extends Permission
     }
 
     /**
-     * Returns a new PermissionCollection object for storing BasicPermission
-     * objects.
+     * Returns a new {@code PermissionCollection} object for storing
+     * {@code BasicPermission} objects.
      *
-     * <p>BasicPermission objects must be stored in a manner that allows them
-     * to be inserted in any order, but that also enables the
-     * PermissionCollection {@code implies} method
+     * <p>{@code BasicPermission} objects must be stored in a manner
+     * that allows them to be inserted in any order, but that also enables the
+     * {@link PermissionCollection#implies} method
      * to be implemented in an efficient (and consistent) manner.
      *
-     * @return a new PermissionCollection object suitable for
-     * storing BasicPermissions.
+     * @return a new {@code PermissionCollection} object suitable for
+     * storing {@code BasicPermission} objects.
      */
     @Override
     public PermissionCollection newPermissionCollection() {
@@ -258,8 +259,12 @@ public abstract class BasicPermission extends Permission
     }
 
     /**
-     * readObject is called to restore the state of the BasicPermission from
-     * a stream.
+     * {@code readObject} is called to restore the state of the
+     * (@code BasicPermission} from a stream.
+     *
+     * @param  s the {@code ObjectInputStream} from which data is read
+     * @throws IOException if an I/O error occurs
+     * @throws ClassNotFoundException if a serialized class cannot be loaded
      */
     @java.io.Serial
     private void readObject(ObjectInputStream s)
@@ -271,12 +276,12 @@ public abstract class BasicPermission extends Permission
     }
 
     /**
-     * Returns the canonical name of this BasicPermission.
+     * Returns the canonical name of this {@code BasicPermission}.
      * All internal invocations of getName should invoke this method, so
      * that the pre-JDK 1.6 "exitVM" and current "exitVM.*" permission are
      * equivalent in equals/hashCode methods.
      *
-     * @return the canonical name of this BasicPermission.
+     * @return the canonical name of this {@code BasicPermission}.
      */
     final String getCanonicalName() {
         return exitVM ? "exitVM.*" : getName();
@@ -284,14 +289,14 @@ public abstract class BasicPermission extends Permission
 }
 
 /**
- * A BasicPermissionCollection stores a collection
- * of BasicPermission permissions. BasicPermission objects
+ * A {@code BasicPermissionCollection} stores a collection
+ * of {@code BasicPermission} permissions. {@code BasicPermission} objects
  * must be stored in a manner that allows them to be inserted in any
  * order, but enable the implies function to evaluate the implies
  * method in an efficient (and consistent) manner.
  *
- * A BasicPermissionCollection handles comparing a permission like "a.b.c.d.e"
- * with a Permission such as "a.b.*", or "*".
+ * A {@code BasicPermissionCollection} handles comparing a permission
+ * like "a.b.c.d.e" with a {@code Permission} such as "a.b.*", or "*".
  *
  * @see java.security.Permission
  * @see java.security.Permissions
@@ -311,22 +316,22 @@ final class BasicPermissionCollection
     private static final long serialVersionUID = 739301742472979399L;
 
     /**
-      * Key is name, value is permission. All permission objects in
-      * collection must be of the same type.
-      * Not serialized; see serialization section at end of class.
-      */
+     * Key is name, value is permission. All permission objects in
+     * collection must be of the same type.
+     * Not serialized; see serialization section at end of class.
+     */
     private transient ConcurrentHashMap<String, Permission> perms;
 
     /**
-     * This is set to {@code true} if this BasicPermissionCollection
-     * contains a BasicPermission with '*' as its permission name.
+     * This is set to {@code true} if this (@code BasicPermissionCollection}
+     * contains a {code BasicPermission} with '*' as its permission name.
      *
      * @see #serialPersistentFields
      */
     private boolean all_allowed;
 
     /**
-     * The class to which all BasicPermissions in this
+     * The class to which all {@code BasicPermission} objects in this
      * BasicPermissionCollection belong.
      *
      * @see #serialPersistentFields
@@ -344,43 +349,41 @@ final class BasicPermissionCollection
     }
 
     /**
-     * Adds a permission to the BasicPermissions. The key for the hash is
-     * permission.path.
+     * Adds a permission to the {@code BasicPermission} object.
+     * The key for the hash is permission.path.
      *
-     * @param permission the Permission object to add.
+     * @param permission the {@code Permission} object to add.
      *
      * @throws    IllegalArgumentException   if the permission is not a
-     *                                       BasicPermission, or if
+     *                                       {@code BasicPermission}, or if
      *                                       the permission is not of the
-     *                                       same Class as the other
+     *                                       same class as the other
      *                                       permissions in this collection.
      *
-     * @throws    SecurityException   if this BasicPermissionCollection object
-     *                                has been marked readonly
+     * @throws    SecurityException   if this {@code BasicPermissionCollection}
+     *                                object has been marked readonly
      */
     @Override
     public void add(Permission permission) {
-        if (! (permission instanceof BasicPermission))
+        if (!(permission instanceof BasicPermission basicPermission))
             throw new IllegalArgumentException("invalid permission: "+
                                                permission);
         if (isReadOnly())
             throw new SecurityException("attempt to add a Permission to a readonly PermissionCollection");
 
-        BasicPermission bp = (BasicPermission) permission;
-
-        // make sure we only add new BasicPermissions of the same class
+        // make sure we only add new BasicPermission objects of the same class
         // Also check null for compatibility with deserialized form from
         // previous versions.
         if (permClass == null) {
             // adding first permission
-            permClass = bp.getClass();
+            permClass = basicPermission.getClass();
         } else {
-            if (bp.getClass() != permClass)
+            if (basicPermission.getClass() != permClass)
                 throw new IllegalArgumentException("invalid permission: " +
                                                 permission);
         }
 
-        String canonName = bp.getCanonicalName();
+        String canonName = basicPermission.getCanonicalName();
         perms.put(canonName, permission);
 
         // No sync on all_allowed; staleness OK
@@ -396,18 +399,16 @@ final class BasicPermissionCollection
      *
      * @param permission the Permission object to compare
      *
-     * @return true if "permission" is a proper subset of a permission in
-     * the set, false if not.
+     * @return {@code true} if "permission" is a proper subset of a
+     * permission in the set, {@code false} if not.
      */
     @Override
     public boolean implies(Permission permission) {
-        if (! (permission instanceof BasicPermission))
+        if (!(permission instanceof BasicPermission basicPermission))
             return false;
 
-        BasicPermission bp = (BasicPermission) permission;
-
         // random subclasses of BasicPermission do not imply each other
-        if (bp.getClass() != permClass)
+        if (basicPermission.getClass() != permClass)
             return false;
 
         // short circuit if the "*" Permission was added
@@ -418,7 +419,7 @@ final class BasicPermissionCollection
         // Check for full match first. Then work our way up the
         // path looking for matches on a.b..*
 
-        String path = bp.getCanonicalName();
+        String path = basicPermission.getCanonicalName();
         //System.out.println("check "+path);
 
         Permission x = perms.get(path);
@@ -470,16 +471,19 @@ final class BasicPermissionCollection
     // private Hashtable permissions;
     /**
      * @serialField permissions java.util.Hashtable
-     *    The BasicPermissions in this BasicPermissionCollection.
-     *    All BasicPermissions in the collection must belong to the same class.
-     *    The Hashtable is indexed by the BasicPermission name; the value
-     *    of the Hashtable entry is the permission.
+     *    The {@code BasicPermission} objects in this
+     *    {@code BasicPermissionCollection}.
+     *    All {@code BasicPermission} objects in the collection must belong
+     *    to the same class.
+     *    The Hashtable is indexed by the {@code BasicPermission} name;
+     *    the value of the Hashtable entry is the permission.
      * @serialField all_allowed boolean
-     *   This is set to {@code true} if this BasicPermissionCollection
-     *   contains a BasicPermission with '*' as its permission name.
+     *   This is set to {@code true} if this {@code BasicPermissionCollection}
+     *   contains a {@code BasicPermission} object
+     *   with '*' as its permission name.
      * @serialField permClass java.lang.Class
-     *   The class to which all BasicPermissions in this
-     *   BasicPermissionCollection belongs.
+     *   The class to which all {@code BasicPermission} objectss in this
+     *   {@code BasicPermissionCollection} belongs.
      */
     @java.io.Serial
     private static final ObjectStreamField[] serialPersistentFields = {
@@ -488,13 +492,17 @@ final class BasicPermissionCollection
         new ObjectStreamField("permClass", Class.class),
     };
 
-    /**
+    /*
      * @serialData Default fields.
      */
-    /*
+
+    /**
      * Writes the contents of the perms field out as a Hashtable for
      * serialization compatibility with earlier releases. all_allowed
      * and permClass unchanged.
+     *
+     * @param  out the {@code ObjectOutputStream} to which data is written
+     * @throws IOException if an I/O error occurs
      */
     @java.io.Serial
     private void writeObject(ObjectOutputStream out) throws IOException {
@@ -516,7 +524,11 @@ final class BasicPermissionCollection
 
     /**
      * readObject is called to restore the state of the
-     * BasicPermissionCollection from a stream.
+     * {@code BasicPermissionCollection} from a stream.
+     *
+     * @param  in the {@code ObjectInputStream} from which data is read
+     * @throws IOException if an I/O error occurs
+     * @throws ClassNotFoundException if a serialized class cannot be loaded
      */
     @java.io.Serial
     private void readObject(java.io.ObjectInputStream in)
