@@ -75,6 +75,35 @@ public class FormatData_jgo extends ListResourceBundle {
             "F\u025bl\u00e2y\u025bd\u025b",
             "S\u00e1sid\u025b",
         };
+        final String[] metaValue_generic_narrow_AmPmMarkers = new String[] {
+            "mba\ua78cmba\ua78c",
+            "\u014bka\u202fmb\u0254\u0301t\u202fnji",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "",
+        };
+        final String[] metaValue_MonthNames = new String[] {
+            "Ndu\u014bmbi Sa\u014b",
+            "P\u025bsa\u014b P\u025b\u0301p\u00e1",
+            "P\u025bsa\u014b P\u025b\u0301t\u00e1t",
+            "P\u025bsa\u014b P\u025b\u0301n\u025b\u0301kwa",
+            "P\u025bsa\u014b Pataa",
+            "P\u025bsa\u014b P\u025b\u0301n\u025b\u0301nt\u00fak\u00fa",
+            "P\u025bsa\u014b Saamb\u00e1",
+            "P\u025bsa\u014b P\u025b\u0301n\u025b\u0301f\u0254m",
+            "P\u025bsa\u014b P\u025b\u0301n\u025b\u0301pf\u00fa\ua78b\u00fa",
+            "P\u025bsa\u014b N\u025bg\u025b\u0301m",
+            "P\u025bsa\u014b Nts\u0254\u030cpm\u0254\u0301",
+            "P\u025bsa\u014b Nts\u0254\u030cpp\u00e1",
+            "",
+        };
         final String[] metaValue_generic_DayNarrows = new String[] {
             "S\u0254\u0301",
             "M\u0254\u0301",
@@ -104,6 +133,16 @@ public class FormatData_jgo extends ListResourceBundle {
             "HH:mm:ss",
             "HH:mm",
         };
+        final String[] metaValue_generic_DateTimePatterns = new String[] {
+            "{1} {0}",
+            "{1} {0}",
+            "{1} {0}",
+            "{1} {0}",
+        };
+        final String metaValue_generic_DateFormatItem_Md = "d.M";
+        final String metaValue_generic_DateFormatItem_Ed = "E d";
+        final String metaValue_generic_DateFormatItem_MEd = "E, d.M";
+        final String metaValue_generic_DateFormatItem_yMd = "M.d.y";
         final String[] metaValue_java_time_generic_DatePatterns = new String[] {
             "EEEE, G y MMMM dd",
             "G y MMMM d",
@@ -116,31 +155,6 @@ public class FormatData_jgo extends ListResourceBundle {
             "GGGG y MMM d",
             "G y-MM-dd",
         };
-        final String[] metaValue_generic_DateTimePatterns = new String[] {
-            "{1} {0}",
-            "{1} {0}",
-            "{1} {0}",
-            "{1} {0}",
-        };
-        final String metaValue_generic_DateFormatItem_Md = "d.M";
-        final String metaValue_generic_DateFormatItem_Ed = "E d";
-        final String metaValue_generic_DateFormatItem_MEd = "E, d.M";
-        final String metaValue_generic_DateFormatItem_yMd = "M.d.y";
-        final String[] metaValue_MonthNames = new String[] {
-            "Ndu\u014bmbi Sa\u014b",
-            "P\u025bsa\u014b P\u025b\u0301p\u00e1",
-            "P\u025bsa\u014b P\u025b\u0301t\u00e1t",
-            "P\u025bsa\u014b P\u025b\u0301n\u025b\u0301kwa",
-            "P\u025bsa\u014b Pataa",
-            "P\u025bsa\u014b P\u025b\u0301n\u025b\u0301nt\u00fak\u00fa",
-            "P\u025bsa\u014b Saamb\u00e1",
-            "P\u025bsa\u014b P\u025b\u0301n\u025b\u0301f\u0254m",
-            "P\u025bsa\u014b P\u025b\u0301n\u025b\u0301pf\u00fa\ua78b\u00fa",
-            "P\u025bsa\u014b N\u025bg\u025b\u0301m",
-            "P\u025bsa\u014b Nts\u0254\u030cpm\u0254\u0301",
-            "P\u025bsa\u014b Nts\u0254\u030cpp\u00e1",
-            "",
-        };
         final String[] metaValue_buddhist_MonthNarrows = new String[] {
             "1",
             "2",
@@ -158,40 +172,129 @@ public class FormatData_jgo extends ListResourceBundle {
         };
         final String metaValue_calendarname_gregorian = "m\u025bl\u025b\u0301\ua78c-m\u025bk\u00e1t";
         final Object[][] data = new Object[][] {
-            { "MonthNames", metaValue_MonthNames },
+            { "generic.DayNames", metaValue_generic_DayNames },
+            { "generic.DayAbbreviations", metaValue_generic_DayNames },
+            { "generic.DayNarrows", metaValue_generic_DayNarrows },
+            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "generic.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
             { "generic.DatePatterns", metaValue_generic_DatePatterns },
-            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "roc.MonthNarrows", metaValue_buddhist_MonthNarrows },
-            { "japanese.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
-            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
-            { "narrow.Eras",
-                new String[] {
-                    "BCE",
-                    "CE",
-                }
-            },
-            { "abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "japanese.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "japanese.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
-            { "japanese.MonthNames", metaValue_MonthNames },
+            { "generic.DateTimePatterns", metaValue_generic_DateTimePatterns },
+            { "generic.DateFormatItem.yyyyMd", "M.d.y G" },
+            { "generic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "generic.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "generic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "MonthNames", metaValue_MonthNames },
+            { "standalone.MonthNames", metaValue_MonthNames },
+            { "MonthAbbreviations", metaValue_MonthNames },
+            { "standalone.MonthAbbreviations", metaValue_MonthNames },
+            { "DayNames", metaValue_generic_DayNames },
+            { "standalone.DayNames", metaValue_generic_DayNames },
+            { "DayAbbreviations", metaValue_generic_DayNames },
             { "standalone.DayAbbreviations", metaValue_generic_DayNames },
-            { "islamic-civil.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "roc.MonthAbbreviations", metaValue_MonthNames },
+            { "DayNarrows", metaValue_generic_DayNarrows },
+            { "standalone.DayNarrows", metaValue_generic_DayNarrows },
+            { "AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "long.Eras",
                 new String[] {
                     "ts\u025btts\u025bt m\u025b\u014bgu\ua78c mi \u025b\u0301 l\u025b\u025bn\u025b K\u025bl\u00eds\u025bt\u0254 g\u0254 \u0144\u0254\u0301",
                     "ts\u025btts\u025bt m\u025b\u014bgu\ua78c mi \u025b\u0301 f\u00fan\u025b K\u025bl\u00eds\u025bt\u0254 t\u0254\u0301 m\u0254\u0301",
                 }
             },
-            { "islamic.DayNames", metaValue_generic_DayNames },
-            { "buddhist.MonthAbbreviations", metaValue_MonthNames },
-            { "generic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "narrow.Eras",
+                new String[] {
+                    "BCE",
+                    "CE",
+                }
+            },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, y MMMM dd",
+                    "y MMMM d",
+                    "y MMM d",
+                    "y-MM-dd",
+                }
+            },
             { "DateTimePatterns", metaValue_generic_DateTimePatterns },
+            { "PluralRules", "one:n = 1" },
+            { "DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.MonthAbbreviations", metaValue_MonthNames },
+            { "buddhist.MonthNarrows", metaValue_buddhist_MonthNarrows },
+            { "buddhist.DayNames", metaValue_generic_DayNames },
+            { "buddhist.DayAbbreviations", metaValue_generic_DayNames },
+            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
+            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
+            { "buddhist.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "buddhist.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "buddhist.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "japanese.MonthNames", metaValue_MonthNames },
+            { "japanese.MonthAbbreviations", metaValue_MonthNames },
+            { "japanese.MonthNarrows", metaValue_buddhist_MonthNarrows },
+            { "japanese.DayNames", metaValue_generic_DayNames },
+            { "japanese.DayAbbreviations", metaValue_generic_DayNames },
+            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
+            { "japanese.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "japanese.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "japanese.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "roc.MonthNames", metaValue_MonthNames },
+            { "roc.MonthAbbreviations", metaValue_MonthNames },
+            { "roc.MonthNarrows", metaValue_buddhist_MonthNarrows },
+            { "roc.DayNames", metaValue_generic_DayNames },
+            { "roc.DayAbbreviations", metaValue_generic_DayNames },
+            { "roc.DayNarrows", metaValue_generic_DayNarrows },
+            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "roc.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "roc.DatePatterns", metaValue_generic_DatePatterns },
+            { "roc.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "roc.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "roc.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "islamic.DayNames", metaValue_generic_DayNames },
+            { "islamic.DayAbbreviations", metaValue_generic_DayNames },
+            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
+            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
+            { "islamic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "islamic.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "islamic-civil.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "islamic-civil.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic-civil.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "islamic-umalqura.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "islamic-umalqura.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
+            { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic-umalqura.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "calendarname.gregory", metaValue_calendarname_gregorian },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -209,90 +312,6 @@ public class FormatData_jgo extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
-            { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "buddhist.DayNames", metaValue_generic_DayNames },
-            { "buddhist.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "islamic-civil.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
-            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
-            { "generic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "buddhist.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
-            { "DayAbbreviations", metaValue_generic_DayNames },
-            { "DayNarrows", metaValue_generic_DayNarrows },
-            { "roc.DatePatterns", metaValue_generic_DatePatterns },
-            { "buddhist.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "generic.TimePatterns", metaValue_generic_TimePatterns },
-            { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "generic.DayAbbreviations", metaValue_generic_DayNames },
-            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
-            { "standalone.MonthAbbreviations", metaValue_MonthNames },
-            { "japanese.MonthNarrows", metaValue_buddhist_MonthNarrows },
-            { "roc.DayAbbreviations", metaValue_generic_DayNames },
-            { "standalone.DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic-umalqura.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
-            { "islamic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "generic.DateTimePatterns", metaValue_generic_DateTimePatterns },
-            { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "TimePatterns", metaValue_generic_TimePatterns },
-            { "islamic.DayNarrows", metaValue_generic_DayNarrows },
-            { "generic.DayNarrows", metaValue_generic_DayNarrows },
-            { "buddhist.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "roc.DayNames", metaValue_generic_DayNames },
-            { "islamic-civil.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
-            { "generic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "generic.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
-            { "islamic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
-            { "japanese.MonthAbbreviations", metaValue_MonthNames },
-            { "islamic.DayAbbreviations", metaValue_generic_DayNames },
-            { "generic.DayNames", metaValue_generic_DayNames },
-            { "islamic-umalqura.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "islamic-umalqura.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
-            { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
-            { "japanese.DayNames", metaValue_generic_DayNames },
-            { "japanese.DayAbbreviations", metaValue_generic_DayNames },
-            { "roc.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
-            { "DayNames", metaValue_generic_DayNames },
-            { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
-            { "DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "roc.MonthNames", metaValue_MonthNames },
-            { "roc.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "roc.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
-            { "buddhist.MonthNarrows", metaValue_buddhist_MonthNarrows },
-            { "islamic.DateFormatItem.Ed", metaValue_generic_DateFormatItem_Ed },
-            { "roc.DayNarrows", metaValue_generic_DayNarrows },
-            { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
-            { "generic.DateFormatItem.yyyyMd", "M.d.y G" },
-            { "roc.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "islamic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
-            { "calendarname.gregorian", metaValue_calendarname_gregorian },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE, y MMMM dd",
-                    "y MMMM d",
-                    "y MMM d",
-                    "y-MM-dd",
-                }
-            },
-            { "buddhist.DayAbbreviations", metaValue_generic_DayNames },
-            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
-            { "standalone.DayNames", metaValue_generic_DayNames },
-            { "MonthAbbreviations", metaValue_MonthNames },
-            { "generic.narrow.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "PluralRules", "one:n = 1" },
-            { "buddhist.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
-            { "generic.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "standalone.MonthNames", metaValue_MonthNames },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -301,11 +320,6 @@ public class FormatData_jgo extends ListResourceBundle {
                     "",
                 }
             },
-            { "buddhist.DayNarrows", metaValue_generic_DayNarrows },
-            { "japanese.DayNarrows", metaValue_generic_DayNarrows },
-            { "roc.TimePatterns", metaValue_generic_TimePatterns },
-            { "roc.abbreviated.AmPmMarkers", metaValue_generic_AmPmMarkers },
-            { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
     }
