@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,30 +67,170 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "AED", "AED" },
             { "AFN", "\u060b" },
+            { "ALL", "ALL" },
+            { "AMD", "AMD" },
+            { "ANG", "ANG" },
+            { "AOA", "AOA" },
+            { "ARS", "ARS" },
+            { "AWG", "AWG" },
+            { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
+            { "BHD", "BHD" },
+            { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
+            { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
             { "CAD", "$CA" },
+            { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
+            { "CNH", "CNH" },
             { "CNY", "\u00a5CN" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
+            { "CVE", "CVE" },
+            { "CZK", "CZK" },
+            { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
+            { "DZD", "DZD" },
+            { "EGP", "EGP" },
+            { "ERN", "ERN" },
+            { "ETB", "ETB" },
+            { "FJD", "FJD" },
+            { "FKP", "FKP" },
+            { "GEL", "GEL" },
+            { "GHS", "GHS" },
+            { "GIP", "GIP" },
+            { "GMD", "GMD" },
+            { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
             { "HKD", "$HK" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
+            { "IQD", "IQD" },
             { "IRR", "\u0631\u06cc\u0627\u0644" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
+            { "JOD", "JOD" },
             { "JPY", "\u00a5" },
+            { "KES", "KES" },
+            { "KGS", "KGS" },
+            { "KHR", "KHR" },
+            { "KMF", "KMF" },
+            { "KPW", "KPW" },
+            { "KWD", "KWD" },
+            { "KYD", "KYD" },
+            { "KZT", "KZT" },
+            { "LAK", "LAK" },
+            { "LBP", "LBP" },
+            { "LKR", "LKR" },
+            { "LRD", "LRD" },
+            { "LSL", "LSL" },
             { "LTL", "LTL" },
             { "LVL", "LVL" },
+            { "LYD", "LYD" },
+            { "MAD", "MAD" },
+            { "MDL", "MDL" },
+            { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
+            { "MRO", "MRO" },
+            { "MRU", "MRU" },
+            { "MUR", "MUR" },
+            { "MVR", "MVR" },
+            { "MWK", "MWK" },
             { "MXN", "$MX" },
             { "MXP", "MXP" },
+            { "MYR", "MYR" },
+            { "MZN", "MZN" },
+            { "NAD", "NAD" },
+            { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
             { "NZD", "$NZ" },
+            { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
+            { "PGK", "PGK" },
+            { "PHP", "PHP" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
+            { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
+            { "RWF", "RWF" },
+            { "SAR", "SAR" },
+            { "SBD", "SBD" },
+            { "SCR", "SCR" },
+            { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
+            { "SHP", "SHP" },
+            { "SLL", "SLL" },
+            { "SOS", "SOS" },
+            { "SRD", "SRD" },
+            { "SSP", "SSP" },
+            { "STD", "STD" },
+            { "STN", "STN" },
+            { "SYP", "SYP" },
+            { "SZL", "SZL" },
             { "THB", "\u0e3f" },
+            { "TJS", "TJS" },
+            { "TMT", "TMT" },
+            { "TND", "TND" },
+            { "TOP", "TOP" },
+            { "TRY", "TRY" },
+            { "TTD", "TTD" },
+            { "TZS", "TZS" },
+            { "UAH", "UAH" },
+            { "UGX", "UGX" },
             { "USD", "$" },
             { "USN", "USN" },
             { "USS", "USS" },
+            { "UYU", "UYU" },
+            { "UZS", "UZS" },
+            { "VEF", "VEF" },
+            { "VES", "VES" },
+            { "VUV", "VUV" },
+            { "WST", "WST" },
             { "XCD", "$EC" },
+            { "XOF", "\u0641\u0631\u0627\u0646\u06a9\u202fCFA" },
+            { "YER", "YER" },
+            { "ZAR", "ZAR" },
+            { "ZMW", "ZMW" },
             { "adp", "\u067e\u0632\u062a\u0627\u06cc \u0622\u0646\u062f\u0648\u0631\u0627" },
             { "aed", "\u062f\u0631\u0647\u0645 \u0627\u0645\u0627\u0631\u0627\u062a \u0645\u062a\u062d\u062f\u0647\u0654 \u0639\u0631\u0628\u06cc" },
             { "afa", "\u0627\u0641\u063a\u0627\u0646\u06cc \u0627\u0641\u063a\u0627\u0646\u0633\u062a\u0627\u0646 (\u06f1\u06f9\u06f2\u06f7 \u062a\u0627 \u06f2\u06f0\u06f0\u06f2)" },
             { "afn", "\u0627\u0641\u063a\u0627\u0646\u06cc \u0627\u0641\u063a\u0627\u0646\u0633\u062a\u0627\u0646" },
+            { "alk", "\u0644\u06a9 \u0622\u0644\u0628\u0627\u0646\u06cc (\u06f1\u06f9\u06f4\u06f6 \u062a\u0627 \u06f1\u06f9\u06f6\u06f5)" },
             { "all", "\u0644\u06a9 \u0622\u0644\u0628\u0627\u0646\u06cc" },
             { "amd", "\u062f\u0631\u0627\u0645 \u0627\u0631\u0645\u0646\u0633\u062a\u0627\u0646" },
             { "ang", "\u06af\u06cc\u0644\u062f\u0631 \u0622\u0646\u062a\u06cc\u0644 \u0647\u0644\u0646\u062f" },
             { "aoa", "\u06a9\u0648\u0627\u0646\u0632\u0627\u06cc \u0622\u0646\u06af\u0648\u0644\u0627" },
+            { "arm", "\u067e\u0632\u0648\u06cc \u0622\u0631\u0698\u0627\u0646\u062a\u06cc\u0646 (\u06f1\u06f8\u06f8\u06f1 \u062a\u0627 \u06f1\u06f9\u06f7\u06f0)" },
             { "arp", "\u067e\u0632\u0648\u06cc \u0622\u0631\u0698\u0627\u0646\u062a\u06cc\u0646 (\u06f1\u06f9\u06f8\u06f3 \u062a\u0627 \u06f1\u06f9\u06f8\u06f5)\u200f" },
             { "ars", "\u067e\u0632\u0648\u06cc \u0622\u0631\u0698\u0627\u0646\u062a\u06cc\u0646" },
             { "ats", "\u0634\u06cc\u0644\u06cc\u0646\u06af \u0627\u062a\u0631\u06cc\u0634" },
@@ -119,8 +255,8 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "bsd", "\u062f\u0644\u0627\u0631 \u0628\u0627\u0647\u0627\u0645\u0627" },
             { "btn", "\u0627\u0646\u06af\u0648\u0644\u062a\u0631\u0648\u0645 \u0628\u0648\u062a\u0627\u0646" },
             { "bwp", "\u067e\u0648\u0644\u0627\u06cc \u0628\u0648\u062a\u0633\u0648\u0627\u0646\u0627" },
-            { "byb", "\u0631\u0648\u0628\u0644 \u062c\u062f\u06cc\u062f \u0628\u06cc\u0644\u0648\u0631\u0648\u0633\u06cc (\u06f1\u06f9\u06f9\u06f4 \u062a\u0627 \u06f1\u06f9\u06f9\u06f9)" },
-            { "byn", "\u0631\u0648\u0628\u0644 \u0628\u0644\u0627\u0631\u0648\u0633\u06cc" },
+            { "byb", "\u0631\u0648\u0628\u0644 \u062c\u062f\u06cc\u062f \u0628\u0644\u0627\u0631\u0648\u0633 (\u06f1\u06f9\u06f9\u06f4 \u062a\u0627 \u06f1\u06f9\u06f9\u06f9)" },
+            { "byn", "\u0631\u0648\u0628\u0644 \u0628\u0644\u0627\u0631\u0648\u0633" },
             { "byr", "\u0631\u0648\u0628\u0644 \u0628\u0644\u0627\u0631\u0648\u0633\u06cc (\u06f2\u06f0\u06f1\u06f6\u2013\u06f2\u06f0\u06f0\u06f0)" },
             { "bzd", "\u062f\u0644\u0627\u0631 \u0628\u0644\u06cc\u0632" },
             { "cad", "\u062f\u0644\u0627\u0631 \u06a9\u0627\u0646\u0627\u062f\u0627" },
@@ -143,8 +279,10 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "dkk", "\u06a9\u0631\u0648\u0646 \u062f\u0627\u0646\u0645\u0627\u0631\u06a9" },
             { "dop", "\u067e\u0632\u0648\u06cc \u062c\u0645\u0647\u0648\u0631\u06cc \u062f\u0648\u0645\u06cc\u0646\u06cc\u06a9\u0646" },
             { "dzd", "\u062f\u06cc\u0646\u0627\u0631 \u0627\u0644\u062c\u0632\u0627\u06cc\u0631" },
+            { "eek", "\u06a9\u0631\u0648\u0646 \u0627\u0633\u062a\u0648\u0646\u06cc" },
             { "egp", "\u067e\u0648\u0646\u062f \u0645\u0635\u0631" },
             { "ern", "\u0646\u0627\u06a9\u0641\u0627\u06cc \u0627\u0631\u06cc\u062a\u0631\u0647" },
+            { "esp", "\u067e\u0632\u062a\u0627\u06cc \u0627\u0633\u067e\u0627\u0646\u06cc\u0627" },
             { "etb", "\u0628\u06cc\u0631 \u0627\u062a\u06cc\u0648\u067e\u06cc" },
             { "eur", "\u06cc\u0648\u0631\u0648" },
             { "fjd", "\u062f\u0644\u0627\u0631 \u0641\u06cc\u062c\u06cc" },
@@ -168,10 +306,13 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "huf", "\u0641\u0648\u0631\u06cc\u0646\u062a \u0645\u062c\u0627\u0631\u0633\u062a\u0627\u0646" },
             { "idr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0627\u0646\u062f\u0648\u0646\u0632\u06cc" },
             { "iep", "\u067e\u0648\u0646\u062f \u0627\u06cc\u0631\u0644\u0646\u062f" },
+            { "ilp", "\u067e\u0648\u0646\u062f \u0627\u0633\u0631\u0627\u0626\u06cc\u0644" },
+            { "ilr", "\u0634\u0642\u0644 \u0627\u0633\u0631\u0627\u0626\u06cc\u0644 (\u06f1\u06f9\u06f8\u06f0 \u062a\u0627 \u06f1\u06f9\u06f8\u06f5)" },
             { "ils", "\u0634\u0642\u0644 \u062c\u062f\u06cc\u062f \u0627\u0633\u0631\u0627\u0626\u06cc\u0644" },
             { "inr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0647\u0646\u062f" },
             { "iqd", "\u062f\u06cc\u0646\u0627\u0631 \u0639\u0631\u0627\u0642" },
             { "irr", "\u0631\u06cc\u0627\u0644 \u0627\u06cc\u0631\u0627\u0646" },
+            { "isj", "\u06a9\u0631\u0648\u0646\u0627\u06cc \u0627\u06cc\u0633\u0644\u0646\u062f (\u06f1\u06f9\u06f1\u06f8 \u062a\u0627 \u06f1\u06f9\u06f8\u06f1)" },
             { "isk", "\u06a9\u0631\u0648\u0646\u0627\u06cc \u0627\u06cc\u0633\u0644\u0646\u062f" },
             { "itl", "\u0644\u06cc\u0631\u0647\u0654 \u0627\u06cc\u062a\u0627\u0644\u06cc\u0627" },
             { "jmd", "\u062f\u0644\u0627\u0631 \u062c\u0627\u0645\u0627\u0626\u06cc\u06a9\u0627" },
@@ -182,6 +323,7 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "khr", "\u0631\u06cc\u200c\u06cc\u0644 \u06a9\u0627\u0645\u0628\u0648\u062c" },
             { "kmf", "\u0641\u0631\u0627\u0646\u06a9 \u06a9\u0648\u0645\u0648\u0631\u0648" },
             { "kpw", "\u0648\u0648\u0646 \u06a9\u0631\u0647\u0654 \u0634\u0645\u0627\u0644\u06cc" },
+            { "kro", "\u0648\u0648\u0646 \u06a9\u0631\u0647\u0654 \u062c\u0646\u0648\u0628\u06cc (\u06f1\u06f9\u06f4\u06f5 \u062a\u0627 \u06f1\u06f9\u06f5\u06f3)" },
             { "krw", "\u0648\u0648\u0646 \u06a9\u0631\u0647\u0654 \u062c\u0646\u0648\u0628\u06cc" },
             { "kwd", "\u062f\u06cc\u0646\u0627\u0631 \u06a9\u0648\u06cc\u062a" },
             { "kyd", "\u062f\u0644\u0627\u0631 \u062c\u0632\u0627\u06cc\u0631 \u06a9\u0650\u06cc\u0645\u0646" },
@@ -192,6 +334,7 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "lrd", "\u062f\u0644\u0627\u0631 \u0644\u06cc\u0628\u0631\u06cc\u0627" },
             { "lsl", "\u0644\u0648\u062a\u06cc \u0644\u0633\u0648\u062a\u0648" },
             { "ltl", "\u0644\u06cc\u062a\u0627\u0633 \u0644\u06cc\u062a\u0648\u0627\u0646\u06cc" },
+            { "ltt", "\u062a\u0627\u0644\u0648\u0646\u0627\u0633 \u0644\u06cc\u062a\u0648\u0627\u0646\u06cc" },
             { "luf", "\u0641\u0631\u0627\u0646\u06a9 \u0644\u0648\u06a9\u0632\u0627\u0645\u0628\u0648\u0631\u06af" },
             { "lul", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0627\u0644\u06cc \u0644\u0648\u06af\u0632\u0627\u0645\u0628\u0648\u0631\u06af" },
             { "lvl", "\u0644\u0627\u062a\u0633 \u0644\u062a\u0648\u0646\u06cc" },
@@ -199,10 +342,12 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "lyd", "\u062f\u06cc\u0646\u0627\u0631 \u0644\u06cc\u0628\u06cc" },
             { "mad", "\u062f\u0631\u0647\u0645 \u0645\u0631\u0627\u06a9\u0634" },
             { "maf", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0631\u0627\u06a9\u0634" },
+            { "mcf", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0648\u0646\u0627\u06a9\u0648" },
             { "mdl", "\u0644\u0626\u0648\u06cc \u0645\u0648\u0644\u062f\u0627\u0648\u06cc" },
             { "mga", "\u0622\u0631\u06cc\u0627\u0631\u06cc \u0645\u0627\u0644\u0627\u06af\u0627\u0633\u06cc" },
             { "mgf", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0627\u062f\u0627\u06af\u0627\u0633\u06a9\u0627\u0631" },
             { "mkd", "\u062f\u06cc\u0646\u0627\u0631 \u0645\u0642\u062f\u0648\u0646\u06cc\u0647" },
+            { "mkn", "\u062f\u06cc\u0646\u0627\u0631 \u0645\u0642\u062f\u0648\u0646\u06cc\u0647 (\u06f1\u06f9\u06f9\u06f2 \u062a\u0627 \u06f1\u06f9\u06f9\u06f3)" },
             { "mlf", "\u0641\u0631\u0627\u0646\u06a9 \u0645\u0627\u0644\u06cc" },
             { "mmk", "\u06a9\u06cc\u0627\u062a \u0645\u06cc\u0627\u0646\u0645\u0627\u0631" },
             { "mnt", "\u062a\u0648\u06af\u0631\u06cc\u06a9 \u0645\u063a\u0648\u0644\u0633\u062a\u0627\u0646" },
@@ -212,6 +357,7 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "mtl", "\u0644\u06cc\u0631\u0647\u0654 \u0645\u0627\u0644\u062a" },
             { "mtp", "\u067e\u0648\u0646\u062f \u0645\u0627\u0644\u062a" },
             { "mur", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0645\u0648\u0631\u06cc\u0633" },
+            { "mvp", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0645\u0627\u0644\u062f\u06cc\u0648 (\u06f1\u06f9\u06f4\u06f7 \u062a\u0627 \u06f1\u06f9\u06f8\u06f1)" },
             { "mvr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u0645\u0627\u0644\u062f\u06cc\u0648" },
             { "mwk", "\u06a9\u0648\u0627\u0686\u0627\u06cc \u0645\u0627\u0644\u0627\u0648\u06cc" },
             { "mxn", "\u067e\u0632\u0648\u06cc \u0645\u06a9\u0632\u06cc\u06a9" },
@@ -228,7 +374,9 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "nzd", "\u062f\u0644\u0627\u0631 \u0632\u0644\u0627\u0646\u062f \u0646\u0648" },
             { "omr", "\u0631\u06cc\u0627\u0644 \u0639\u0645\u0627\u0646" },
             { "pab", "\u0628\u0627\u0644\u0628\u0648\u0627\u06cc \u067e\u0627\u0646\u0627\u0645\u0627" },
-            { "pen", "\u0646\u0648\u0626\u0648\u0648\u0633\u0648\u0644 \u067e\u0631\u0648" },
+            { "pei", "\u0627\u06cc\u0646\u062a\u06cc \u067e\u0631\u0648" },
+            { "pen", "\u0633\u0648\u0644 \u067e\u0631\u0648" },
+            { "pes", "\u0633\u0648\u0644 \u067e\u0631\u0648 (\u06f1\u06f8\u06f6\u06f3 \u062a\u0627 \u06f1\u06f9\u06f6\u06f5)" },
             { "pgk", "\u06a9\u06cc\u0646\u0627\u06cc \u067e\u0627\u067e\u0648\u0627 \u06af\u06cc\u0646\u0647\u0654 \u0646\u0648" },
             { "php", "\u067e\u0632\u0648\u06cc \u0641\u06cc\u0644\u06cc\u067e\u06cc\u0646" },
             { "pkr", "\u0631\u0648\u067e\u06cc\u0647\u0654 \u067e\u0627\u06a9\u0633\u062a\u0627\u0646" },
@@ -276,7 +424,7 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "uah", "\u0647\u0631\u06cc\u0648\u0646\u06cc\u0627\u06cc \u0627\u0648\u06a9\u0631\u0627\u06cc\u0646" },
             { "ugs", "\u0634\u06cc\u0644\u06cc\u0646\u06af \u0627\u0648\u06af\u0627\u0646\u062f\u0627 (\u06f1\u06f9\u06f6\u06f6 \u062a\u0627 \u06f1\u06f9\u06f8\u06f7)" },
             { "ugx", "\u0634\u06cc\u0644\u06cc\u0646\u06af \u0627\u0648\u06af\u0627\u0646\u062f\u0627" },
-            { "usd", "\u062f\u0644\u0627\u0631 \u0627\u0645\u0631\u06cc\u06a9\u0627" },
+            { "usd", "\u062f\u0644\u0627\u0631 \u0622\u0645\u0631\u06cc\u06a9\u0627" },
             { "usn", "\u062f\u0644\u0627\u0631 \u0627\u0645\u0631\u06cc\u06a9\u0627 (\u0631\u0648\u0632 \u0628\u0639\u062f)" },
             { "uss", "\u062f\u0644\u0627\u0631 \u0627\u0645\u0631\u06cc\u06a9\u0627 (\u0647\u0645\u0627\u0646 \u0631\u0648\u0632)" },
             { "uyp", "\u067e\u0632\u0648\u06cc \u0627\u0648\u0631\u0648\u06af\u0648\u0626\u0647 (\u06f1\u06f9\u06f7\u06f5 \u062a\u0627 \u06f1\u06f9\u06f9\u06f3)" },
@@ -297,6 +445,7 @@ public class CurrencyNames_fa extends OpenListResourceBundle {
             { "xpd", "\u067e\u0627\u0644\u0627\u062f\u06cc\u0645" },
             { "xpf", "\u0641\u0631\u0627\u0646\u06a9 \u0627\u0642\u06cc\u0627\u0646\u0648\u0633\u06cc\u0647" },
             { "xpt", "\u067e\u0644\u0627\u062a\u06cc\u0646" },
+            { "xts", "\u0627\u0631\u0632 \u0622\u0632\u0645\u0627\u06cc\u0634\u06cc" },
             { "xxx", "\u0627\u0631\u0632 \u0646\u0627\u0645\u0634\u062e\u0635" },
             { "ydd", "\u062f\u06cc\u0646\u0627\u0631 \u06cc\u0645\u0646" },
             { "yer", "\u0631\u06cc\u0627\u0644 \u06cc\u0645\u0646" },
