@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -72,57 +68,125 @@ public class CurrencyNames_fil extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "AED", "AED" },
+            { "AFN", "AFN" },
+            { "ALL", "ALL" },
             { "AMD", "AMD" },
+            { "ANG", "ANG" },
             { "AOA", "AOA" },
+            { "ARS", "ARS" },
+            { "AWG", "AWG" },
             { "AZN", "AZN" },
+            { "BAM", "BAM" },
+            { "BBD", "BBD" },
+            { "BDT", "BDT" },
+            { "BGN", "BGN" },
             { "BHD", "BHD" },
             { "BIF", "BIF" },
+            { "BMD", "BMD" },
+            { "BND", "BND" },
+            { "BOB", "BOB" },
+            { "BSD", "BSD" },
+            { "BTN", "BTN" },
             { "BWP", "BWP" },
+            { "BYN", "BYN" },
+            { "BYR", "BYR" },
+            { "BZD", "BZD" },
             { "CDF", "CDF" },
+            { "CHF", "CHF" },
+            { "CLP", "CLP" },
+            { "CNH", "CNH" },
+            { "COP", "COP" },
+            { "CRC", "CRC" },
+            { "CUC", "CUC" },
+            { "CUP", "CUP" },
             { "CVE", "CVE" },
+            { "CZK", "CZK" },
             { "DJF", "DJF" },
+            { "DKK", "DKK" },
+            { "DOP", "DOP" },
             { "DZD", "DZD" },
             { "EGP", "EGP" },
             { "ERN", "ERN" },
             { "ETB", "ETB" },
             { "FJD", "FJD" },
+            { "FKP", "FKP" },
             { "GEL", "GEL" },
             { "GHS", "GHS" },
+            { "GIP", "GIP" },
             { "GMD", "GMD" },
             { "GNF", "GNF" },
+            { "GTQ", "GTQ" },
+            { "GYD", "GYD" },
+            { "HNL", "HNL" },
+            { "HRK", "HRK" },
+            { "HTG", "HTG" },
+            { "HUF", "HUF" },
+            { "IDR", "IDR" },
             { "IQD", "IQD" },
+            { "IRR", "IRR" },
+            { "ISK", "ISK" },
+            { "JMD", "JMD" },
             { "JOD", "JOD" },
             { "JPY", "\u00a5" },
             { "KES", "KES" },
             { "KGS", "KGS" },
+            { "KHR", "KHR" },
             { "KMF", "KMF" },
+            { "KPW", "KPW" },
             { "KWD", "KWD" },
+            { "KYD", "KYD" },
             { "KZT", "KZT" },
+            { "LAK", "LAK" },
             { "LBP", "LBP" },
+            { "LKR", "LKR" },
             { "LRD", "LRD" },
+            { "LTL", "LTL" },
+            { "LVL", "LVL" },
             { "LYD", "LYD" },
             { "MAD", "MAD" },
+            { "MDL", "MDL" },
             { "MGA", "MGA" },
+            { "MKD", "MKD" },
+            { "MMK", "MMK" },
+            { "MNT", "MNT" },
+            { "MOP", "MOP" },
             { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MUR", "MUR" },
+            { "MVR", "MVR" },
             { "MWK", "MWK" },
+            { "MYR", "MYR" },
             { "MZN", "MZN" },
             { "NAD", "NAD" },
             { "NGN", "NGN" },
+            { "NIO", "NIO" },
+            { "NOK", "NOK" },
+            { "NPR", "NPR" },
             { "OMR", "OMR" },
+            { "PAB", "PAB" },
+            { "PEN", "PEN" },
             { "PGK", "PGK" },
-            { "PHP", "\u20b1" },
+            { "PKR", "PKR" },
+            { "PLN", "PLN" },
+            { "PYG", "PYG" },
             { "QAR", "QAR" },
+            { "RON", "RON" },
+            { "RSD", "RSD" },
+            { "RUB", "RUB" },
             { "RWF", "RWF" },
             { "SAR", "SAR" },
             { "SBD", "SBD" },
             { "SCR", "SCR" },
             { "SDG", "SDG" },
+            { "SEK", "SEK" },
+            { "SGD", "SGD" },
             { "SHP", "SHP" },
             { "SLL", "SLL" },
             { "SOS", "SOS" },
+            { "SRD", "SRD" },
             { "SSP", "SSP" },
             { "STD", "STD" },
+            { "STN", "STN" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
             { "THB", "\u0e3f" },
@@ -131,10 +195,15 @@ public class CurrencyNames_fil extends OpenListResourceBundle {
             { "TND", "TND" },
             { "TOP", "TOP" },
             { "TRY", "TRY" },
+            { "TTD", "TTD" },
             { "TZS", "TZS" },
+            { "UAH", "UAH" },
             { "UGX", "UGX" },
             { "USD", "$" },
+            { "UYU", "UYU" },
             { "UZS", "UZS" },
+            { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VUV", "VUV" },
             { "WST", "WST" },
             { "YER", "YER" },
@@ -142,7 +211,7 @@ public class CurrencyNames_fil extends OpenListResourceBundle {
             { "ZMW", "ZMW" },
             { "aed", "United Arab Emirates Dirham" },
             { "afn", "Afghan Afghani" },
-            { "all", "Albanian Lek" },
+            { "all", "Lek ng Albania" },
             { "amd", "Armenian Dram" },
             { "ang", "Antillean Guilder ng Netherlands" },
             { "aoa", "Angolan Kwanza" },
@@ -163,27 +232,28 @@ public class CurrencyNames_fil extends OpenListResourceBundle {
             { "bsd", "Dolyar ng Bahamas" },
             { "btn", "Bhutanese Ngultrum" },
             { "bwp", "Botswanan Pula" },
-            { "byn", "Belarusian Ruble" },
+            { "byn", "Ruble ng Belarus" },
             { "byr", "Belarusian Ruble (2000\u20132016)" },
             { "bzd", "Dolyar ng Belize" },
             { "cad", "Dolyar ng Canada" },
             { "cdf", "Congolese Franc" },
             { "chf", "Swiss Franc" },
             { "clp", "Piso ng Chile" },
+            { "cnh", "Chinese Yuan (offshore)" },
             { "cny", "Chinese Yuan" },
             { "cop", "Piso ng Colombia" },
             { "crc", "Col\u00f3n ng Costa Rica" },
             { "cuc", "Convertible na Piso ng Cuba" },
             { "cup", "Piso ng Cuba" },
             { "cve", "Cape Verdean Escudo" },
-            { "czk", "Czech Republic Koruna" },
+            { "czk", "Koruna ng Czech Republic" },
             { "dem", "Deutsche Marks" },
             { "djf", "Djiboutian Franc" },
             { "dkk", "Danish Krone" },
             { "dop", "Piso ng Dominican" },
             { "dzd", "Algerian Dinar" },
             { "eek", "Estonian Kroon" },
-            { "egp", "Egyptian Pound" },
+            { "egp", "Pound ng Egypt" },
             { "ern", "Eritrean Nakfa" },
             { "etb", "Ethiopian Birr" },
             { "eur", "Euro" },
@@ -193,18 +263,18 @@ public class CurrencyNames_fil extends OpenListResourceBundle {
             { "gbp", "British Pound" },
             { "gel", "Georgian Lari" },
             { "ghs", "Ghanaian Cedi" },
-            { "gip", "Gibraltar Pound" },
+            { "gip", "Pound ng Gibraltar" },
             { "gmd", "Gambian Dalasi" },
             { "gnf", "Guinean Franc" },
             { "gtq", "Quetzal ng Guatemala" },
             { "gyd", "Dolyar ng Guyanese" },
             { "hkd", "Dolyar ng Hong Kong" },
             { "hnl", "Lempira ng Honduras" },
-            { "hrk", "Croatian Kuna" },
+            { "hrk", "Kuna ng Croatia" },
             { "htg", "Gourde ng Haiti" },
-            { "huf", "Hungarian Forint" },
+            { "huf", "Forint ng Hungary" },
             { "idr", "Indonesian Rupiah" },
-            { "ils", "Israeli New Sheqel" },
+            { "ils", "New Shekel ng Israel" },
             { "inr", "Indian Rupee" },
             { "iqd", "Iraqi Dinar" },
             { "irr", "Iranian Rial" },
@@ -228,11 +298,11 @@ public class CurrencyNames_fil extends OpenListResourceBundle {
             { "lsl", "Lesotho Loti" },
             { "ltl", "Lithuanian Litas" },
             { "lvl", "Latvian Lats" },
-            { "lyd", "Libyan Dinar" },
+            { "lyd", "Dinar ng Libya" },
             { "mad", "Moroccan Dirham" },
-            { "mdl", "Moldovan Leu" },
+            { "mdl", "Leu ng Moldova" },
             { "mga", "Malagasy Ariary" },
-            { "mkd", "Macedonian Denar" },
+            { "mkd", "Denar ng Macedonia" },
             { "mmk", "Myanmar Kyat" },
             { "mnt", "Mongolian Tugrik" },
             { "mop", "Macanese Pataca" },
@@ -256,12 +326,12 @@ public class CurrencyNames_fil extends OpenListResourceBundle {
             { "pgk", "Papua New Guinean Kina" },
             { "php", "Piso ng Pilipinas" },
             { "pkr", "Pakistani Rupee" },
-            { "pln", "Polish Zloty" },
+            { "pln", "Zloty ng Poland" },
             { "pyg", "Paraguayan Guarani" },
             { "qar", "Qatari Rial" },
-            { "ron", "Romanian Leu" },
-            { "rsd", "Serbian Dinar" },
-            { "rub", "Russian Ruble" },
+            { "ron", "Leu ng Romania" },
+            { "rsd", "Dinar ng Serbia" },
+            { "rub", "Ruble ng Russia" },
             { "rwf", "Rwandan Franc" },
             { "sar", "Saudi Riyal" },
             { "sbd", "Dolyar ng Solomon Islands" },
@@ -277,7 +347,7 @@ public class CurrencyNames_fil extends OpenListResourceBundle {
             { "srd", "Dolyar ng Suriname" },
             { "ssp", "Pound ng Timog Sudan" },
             { "std", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (1977\u20132017)" },
-            { "stn", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra (2018)" },
+            { "stn", "S\u00e3o Tom\u00e9 & Pr\u00edncipe Dobra" },
             { "syp", "Syrian Pound" },
             { "szl", "Swazi Lilangeni" },
             { "thb", "Thai Baht" },
@@ -289,7 +359,7 @@ public class CurrencyNames_fil extends OpenListResourceBundle {
             { "ttd", "Dolyar ng Trinidad and Tobago" },
             { "twd", "Dolyar ng New Taiwan" },
             { "tzs", "Tanzanian Shilling" },
-            { "uah", "Ukrainian Hryvnia" },
+            { "uah", "Hryvnia ng Ukraine" },
             { "ugx", "Ugandan Shilling" },
             { "usd", "Dolyar ng US" },
             { "uyu", "Piso ng Uruguay" },
