@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -85,28 +81,31 @@ public class LocaleNames_es_MX extends OpenListResourceBundle {
             { "155", "Europa Occidental" },
             { "BA", "Bosnia y Herzegovina" },
             { "CI", "C\u00f4te d\u2019Ivoire" },
-            { "EZ", "zona euro" },
             { "GG", "Guernsey" },
             { "RO", "Rumania" },
             { "SA", "Arabia Saudita" },
             { "SZ", "Eswatini" },
             { "TA", "Trist\u00e1n de Acu\u00f1a" },
             { "UM", "Islas menores alejadas de EE. UU." },
-            { "UN", "ONU" },
             { "eu", "euskera" },
             { "lo", "lao" },
             { "nr", "ndebele meridional" },
             { "pa", "punyab\u00ed" },
             { "ss", "siswati" },
             { "sw", "suajili" },
-            { "tn", "setswana" },
             { "ace", "acehn\u00e9s" },
+            { "ady", "adigu\u00e9" },
             { "arp", "arapaho" },
+            { "ars", "\u00e1rabe neyed\u00ed" },
             { "bas", "basa" },
             { "bax", "bamun" },
             { "bho", "bhoshpuri" },
             { "bla", "siksika" },
             { "bua", "buriat" },
+            { "crj", "cree del sureste" },
+            { "crl", "cree del noreste" },
+            { "crr", "carolina algonquian" },
+            { "dar", "darguin" },
             { "dum", "neerland\u00e9s medieval" },
             { "enm", "ingl\u00e9s medieval" },
             { "frm", "franc\u00e9s medieval" },
@@ -114,32 +113,32 @@ public class LocaleNames_es_MX extends OpenListResourceBundle {
             { "gmh", "alem\u00e1n de la alta edad media" },
             { "grc", "griego antiguo" },
             { "hak", "kejia (China)" },
+            { "hax", "haida del sur" },
             { "hil", "hiligain\u00f3n" },
             { "hsn", "xiang (China)" },
+            { "ikt", "inuktitut del oeste de Canad\u00e1" },
             { "inh", "ingusetio" },
             { "kbd", "kabardiano" },
+            { "kgp", "kaingang" },
             { "krc", "karach\u00e1i b\u00e1lkaro" },
             { "kum", "cumuco" },
-            { "lus", "lushai" },
             { "mga", "irland\u00e9s medieval" },
             { "nan", "min nan (Chino)" },
             { "nso", "sotho septentrional" },
-            { "pcm", "pcm" },
+            { "ojb", "ojibwa del noroeste" },
+            { "ojw", "ojibwa del oeste" },
             { "shu", "\u00e1rabe chadiano" },
+            { "slh", "lushootseed del sur" },
             { "syr", "siriaco" },
-            { "tet", "tet\u00fan" },
-            { "tyv", "tuviniano" },
-            { "wuu", "wuu" },
-            { "xal", "kalmyk" },
+            { "tce", "tutchone del sur" },
+            { "wuu", "chino wu" },
             { "zgh", "tamazight marroqu\u00ed est\u00e1ndar" },
-            { "Hanb", "hanb" },
-            { "Mlym", "malay\u00e1lam" },
-            { "de_AT", "alem\u00e1n austriaco" },
             { "sw_CD", "suajili del Congo" },
             { "type.ca.roc", "calendario minguo" },
             { "type.nu.gujr", "d\u00edgitos en gujarati" },
+            { "type.nu.mtei", "d\u00edgitos en manipuri" },
+            { "type.nu.olck", "d\u00edgitos ol chiki" },
             { "type.co.ducet", "orden de clasificaci\u00f3n de Unicode predeterminado" },
-            { "type.lb.normal", "salto de l\u00ednea normal" },
         };
         return data;
     }
